==> plasma-desktop_5.12.9.1.orig.tar.xz: plasma-desktop-5.12.9.1/dataengines/kimpanel/kimpanelservice.h <==
/***************************************************************************
 *   Copyright (C) 2011 by CSSlayer <wengxt@gmail.com>                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/

#ifndef KIMPANEL_SERVICE_H
#define KIMPANEL_SERVICE_H

#include <Plasma/Service>

class PanelAgent;
class KimpanelService : public Plasma::Service
{
    Q_OBJECT

public:
    KimpanelService(QObject* parent, const QString& name, PanelAgent* panelAgent);

public slots:
    void enableKimpanelOperations();

protected:
    Plasma::ServiceJob* createJob(const QString &operation, QMap<QString, QVariant> &parameters) Q_DECL_OVERRIDE;

private:
    PanelAgent* m_panelAgent;
};

#endif // KIMPANEL_SERVICE_H

==> plasma-desktop-5.17.2.tar.xz: plasma-desktop-5.17.2/dataengines/kimpanel/kimpanelservice.h <==
/***************************************************************************
 *   Copyright (C) 2011 by CSSlayer <wengxt@gmail.com>                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/

#ifndef KIMPANEL_SERVICE_H
#define KIMPANEL_SERVICE_H

#include <Plasma/Service>

class PanelAgent;
class KimpanelService : public Plasma::Service
{
    Q_OBJECT

public:
    KimpanelService(QObject* parent, const QString& name, PanelAgent* panelAgent);

public slots:
    void enableKimpanelOperations();

protected:
    Plasma::ServiceJob* createJob(const QString &operation, QMap<QString, QVariant> &parameters) override;

private:
    PanelAgent* m_panelAgent;
};

#endif // KIMPANEL_SERVICE_H
